export type { ErrorHandler as IErrorHandler } from "../../../types/js";
export type Result<T, E = Error> = {
    ok: true;
    value: T;
} | {
    ok: false;
    error: E;
};
export declare const ok: <T, E>(value: T) => Result<T, E>;
export declare const okVoid: <E>() => Result<void, E>;
export declare const err: <E = Error>(error: E) => Result<never, E>;
export declare const wrap: <T, R>(fn: (value: T) => R) => (result: Result<T, Error>) => Result<R, Error>;
export declare function match<TSuccess, TError, TReturn>(result: Result<TSuccess, TError>, onSuccess: (value: TSuccess) => TReturn, onError: (error: TError) => TReturn): TReturn;
export declare const wrapThrows: <T, A extends any[]>(fn: (...args: A) => T) => (...args: A) => Result<T, Error>;
export type NetworkError = {
    code: "network_error";
    status: number;
    message: string;
    url: string;
    responseMessage: string;
};
export type MissingFieldError = {
    code: "missing_field";
    field: string;
};
export type InvalidMatchTypeError = {
    code: "invalid_match_type";
    message: string;
};
export type MissingPersonError = {
    code: "missing_person";
    message: string;
};
export type NotInitializedError = {
    code: "not_initialized";
    message: string;
};
export type AttributeAlreadyExistsError = {
    code: "attribute_already_exists";
    message: string;
};
export declare class ErrorHandler {
    private static instance;
    private handleError;
    customized: boolean;
    static initialized: boolean;
    private constructor();
    static getInstance(): ErrorHandler;
    static init(errorHandler?: (error: any) => void): void;
    printStatus(): void;
    handle(error: any): void;
}
